@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import numpy as np
 
-from libecalc.common.serializable_chart import SingleSpeedChartDTO, VariableSpeedChartDTO
+from libecalc.common.serializable_chart import ChartDTO
 from libecalc.common.units import Unit
 from libecalc.domain.process.core.results.compressor import (
     CompressorStageResult,
@@ -203,7 +203,7 @@ class CompressorTrainResultSingleTimeStep:
     @staticmethod
     def from_result_list_to_dto(
         result_list: list[CompressorTrainResultSingleTimeStep],
-        compressor_charts: list[SingleSpeedChartDTO | VariableSpeedChartDTO] | None,
+        compressor_charts: list[ChartDTO] | None,
     ) -> tuple[CompressorStreamCondition, CompressorStreamCondition, list[CompressorStageResult]]:
         number_of_stages = max([len(t.stage_results) for t in result_list])
 
