@@ -9,7 +9,7 @@ import numpy as np
 from libecalc.common.list.list_utils import elementwise_sum
 from libecalc.common.serializable_chart import ChartDTO
 from libecalc.common.units import Unit
-from libecalc.domain.process.core.results.base import EnergyFunctionResult, EnergyModelBaseResult
+from libecalc.domain.process.core.results.base import EnergyFunctionResult, EnergyResult, Quantity
 from libecalc.domain.process.core.results.turbine import TurbineResult
 from libecalc.domain.process.value_objects.chart.chart_area_flag import ChartAreaFlag
 
@@ -43,7 +43,7 @@ class TargetPressureStatus(str, Enum):
     TARGET_PRESSURES_MET = "TARGET_PRESSURES_MET"
 
 
-class CompressorStreamCondition(EnergyModelBaseResult):
+class CompressorStreamCondition:
     def __init__(
         self,
         pressure: Sequence[float] | None = None,
@@ -56,7 +56,6 @@ class CompressorStreamCondition(EnergyModelBaseResult):
         z: Sequence[float] | None = None,
         temperature_kelvin: Sequence[float] | None = None,
     ):
-        super().__init__()
         self.pressure = pressure
         self.actual_rate_m3_per_hr = actual_rate_m3_per_hr
         self.actual_rate_before_asv_m3_per_hr = actual_rate_before_asv_m3_per_hr
@@ -83,33 +82,32 @@ class CompressorStreamCondition(EnergyModelBaseResult):
         )
 
 
-class CompressorStageResult(EnergyModelBaseResult):
+class CompressorStageResult:
     def __init__(
         self,
         energy_usage: Sequence[float],
         energy_usage_unit: Unit,
-        power: Sequence[float] | None = None,
-        power_unit: Unit | None = None,
-        mass_rate_kg_per_hr: Sequence[float] | None = None,
-        mass_rate_before_asv_kg_per_hr: Sequence[float] | None = None,
-        inlet_stream_condition: CompressorStreamCondition = None,
-        outlet_stream_condition: CompressorStreamCondition = None,
-        polytropic_enthalpy_change_kJ_per_kg: Sequence[float] | None = None,
-        polytropic_head_kJ_per_kg: Sequence[float] | None = None,
-        polytropic_efficiency: Sequence[float] | None = None,
-        polytropic_enthalpy_change_before_choke_kJ_per_kg: Sequence[float] | None = None,
-        speed: Sequence[float] | None = None,
-        asv_recirculation_loss_mw: Sequence[float] = None,
-        fluid_composition: dict[str, float | None] = None,
-        is_valid: Sequence[bool] = None,
-        chart_area_flags: Sequence[str] = None,
-        rate_has_recirculation: Sequence[bool] = None,
-        rate_exceeds_maximum: Sequence[bool] = None,
-        pressure_is_choked: Sequence[bool] = None,
-        head_exceeds_maximum: Sequence[bool] = None,
+        power: Sequence[float],
+        power_unit: Unit,
+        mass_rate_kg_per_hr: Sequence[float],
+        mass_rate_before_asv_kg_per_hr: Sequence[float],
+        inlet_stream_condition: CompressorStreamCondition,
+        outlet_stream_condition: CompressorStreamCondition,
+        polytropic_enthalpy_change_kJ_per_kg: Sequence[float],
+        polytropic_head_kJ_per_kg: Sequence[float],
+        polytropic_efficiency: Sequence[float],
+        polytropic_enthalpy_change_before_choke_kJ_per_kg: Sequence[float],
+        speed: Sequence[float],
+        asv_recirculation_loss_mw: Sequence[float],
+        fluid_composition: dict[str, float | None],
+        is_valid: Sequence[bool],
+        chart_area_flags: Sequence[str],
+        rate_has_recirculation: Sequence[bool],
+        rate_exceeds_maximum: Sequence[bool],
+        pressure_is_choked: Sequence[bool],
+        head_exceeds_maximum: Sequence[bool],
         chart: ChartDTO | None = None,
     ):
-        super().__init__()
         self.energy_usage = energy_usage
         self.energy_usage_unit = energy_usage_unit
         self.power = power
@@ -182,15 +180,17 @@ class CompressorTrainResult(EnergyFunctionResult):
     def __init__(
         self,
         rate_sm3_day: Sequence[float] | list[list[float]],
-        max_standard_rate: Sequence[float] | list[list[float]] | None = None,
-        inlet_stream_condition: CompressorStreamCondition = None,
-        outlet_stream_condition: CompressorStreamCondition = None,
-        stage_results: Sequence[CompressorStageResult] = None,
-        failure_status: Sequence[CompressorTrainCommonShaftFailureStatus | None] = None,
-        turbine_result: TurbineResult | None = None,
-        **kwargs,
+        max_standard_rate: Sequence[float] | None,
+        inlet_stream_condition: CompressorStreamCondition,
+        outlet_stream_condition: CompressorStreamCondition,
+        stage_results: Sequence[CompressorStageResult],
+        failure_status: Sequence[CompressorTrainCommonShaftFailureStatus | None],
+        turbine_result: TurbineResult | None,
+        energy_usage: list[float],
+        energy_usage_unit: Unit,
+        power: list[float] | None,
+        power_unit: Unit | None,
     ):
-        super().__init__(**kwargs)
         self.rate_sm3_day = rate_sm3_day
         self.max_standard_rate = max_standard_rate
 
@@ -199,14 +199,45 @@ class CompressorTrainResult(EnergyFunctionResult):
 
         self.stage_results = stage_results
         self.failure_status = failure_status
-        self.turbine_result = turbine_result
+        self._turbine_result = turbine_result
+        self._energy_usage = Quantity(
+            values=energy_usage,
+            unit=energy_usage_unit,
+        )
+
+        if power is not None:
+            assert power_unit is not None
+            self._power = Quantity(
+                values=power,
+                unit=power_unit,
+            )
+        else:
+            self._power = None
 
     @property
     def rate(self) -> list[float]:
         return self.rate_sm3_day
 
     @property
-    def is_valid(self) -> list[bool]:
+    def turbine_result(self) -> TurbineResult:
+        return self._turbine_result
+
+    @turbine_result.setter
+    def turbine_result(self, turbine_result: TurbineResult):
+        turbine_energy_result = turbine_result.get_energy_result()
+        self._power = turbine_energy_result.power
+        self._energy_usage = turbine_energy_result.energy_usage
+        self._turbine_result = turbine_result
+
+    def get_energy_result(self) -> EnergyResult:
+        return EnergyResult(
+            energy_usage=self._energy_usage,
+            power=self._power,
+            is_valid=self._is_valid,
+        )
+
+    @property
+    def _is_valid(self) -> list[bool]:
         """The sampled compressor model behaves "normally" and returns NaN-values when invalid.
         The turbine model can still be invalid if the sampled compressor model is valid (too high load),
         so need to check that as well.
@@ -216,14 +247,17 @@ class CompressorTrainResult(EnergyFunctionResult):
         failure_status_are_valid = [
             t is CompressorTrainCommonShaftFailureStatus.NO_FAILURE for t in self.failure_status
         ]
+
         turbine_are_valid = (
-            self.turbine_result.is_valid if self.turbine_result is not None else [True] * len(self.energy_usage)
+            self.turbine_result.get_energy_result().is_valid
+            if self.turbine_result is not None
+            else [True] * len(self._energy_usage)
         )
 
         stage_results_are_valid = (
             np.all([stage.is_valid for stage in self.stage_results], axis=0)
             if self.stage_results is not None
-            else [not isnan(x) for x in self.energy_usage]
+            else [not isnan(x) for x in self._energy_usage.values]
         )
         return np.all([failure_status_are_valid, turbine_are_valid, stage_results_are_valid], axis=0).tolist()
 
