@@ -1,6 +1,6 @@
 from collections import namedtuple
 from collections.abc import Sequence
-from typing import Any, TypeVar
+from typing import overload
 
 import pandas as pd
 
@@ -10,7 +10,6 @@ from libecalc.common.units import Unit
 from libecalc.domain.component_validation_error import DomainValidationException
 from libecalc.domain.resource import Resource
 from libecalc.dto.types import ChartControlMarginUnit, ChartEfficiencyUnit, ChartPolytropicHeadUnit, ChartRateUnit
-from libecalc.presentation.yaml.domain.reference_service import InvalidReferenceException
 from libecalc.presentation.yaml.yaml_keywords import EcalcYamlKeywords
 from libecalc.presentation.yaml.yaml_types.models.yaml_compressor_chart import YamlCurve
 
@@ -26,38 +25,6 @@ YAML_UNIT_MAPPING: dict[str, Unit] = {
 }
 
 
-def is_reference(value: Any) -> bool:
-    return isinstance(value, str)
-
-
-ReferenceValue = TypeVar("ReferenceValue")
-
-
-def resolve_model_reference(value: Any, references: dict[str, ReferenceValue]) -> ReferenceValue:
-    """Check if value is a reference and return it.
-    If not a reference return the original value
-    If reference is invalid, raise InvalidReferenceException
-
-    :param value: reference or value
-    :param references: mapping from reference name to reference data
-        {
-                reference1: value1,
-                reference2: value2,
-        }
-    :return: the actual value either referenced or not.
-    """
-    if not is_reference(value):
-        return value
-
-    if value not in references:
-        available_references = ",\n".join(references.keys())
-        raise InvalidReferenceException(
-            reference_type="model", reference=value, available_references=available_references
-        )
-
-    return references[value]
-
-
 def convert_rate_to_am3_per_hour(rate_values: list[float], input_unit: Unit) -> list[float]:
     """Convert rate from ay supported rate to Am3/h."""
     if input_unit == Unit.ACTUAL_VOLUMETRIC_M3_PER_HOUR:
@@ -68,7 +35,7 @@ def convert_rate_to_am3_per_hour(rate_values: list[float], input_unit: Unit) ->
             f"Needs to be one of {', '.join(list(ChartRateUnit))}"
         )
         logger.error(msg)
-        raise ValueError(msg)
+        raise DomainValidationException(msg)
 
 
 def convert_head_to_joule_per_kg(head_values: list[float], input_unit: Unit) -> list[float]:
@@ -87,7 +54,7 @@ def convert_head_to_joule_per_kg(head_values: list[float], input_unit: Unit) ->
             f"Must be one of {', '.join(list(ChartPolytropicHeadUnit))}"
         )
         logger.error(msg)
-        raise ValueError(msg)
+        raise DomainValidationException(msg)
 
 
 def convert_head_to_meter_liquid_column(head_values: list[float], input_unit: Unit) -> list[float]:
@@ -106,7 +73,7 @@ def convert_head_to_meter_liquid_column(head_values: list[float], input_unit: Un
             f"Must be one of {', '.join(list(ChartPolytropicHeadUnit))}"
         )
         logger.error(msg)
-        raise ValueError(msg)
+        raise DomainValidationException(msg)
 
 
 def convert_temperature_to_kelvin(temperature_values: list[float], input_unit: Unit) -> list[float]:
@@ -115,7 +82,9 @@ def convert_temperature_to_kelvin(temperature_values: list[float], input_unit: U
     elif input_unit == Unit.CELSIUS:
         return [Unit.CELSIUS.to(Unit.KELVIN)(temperature) for temperature in temperature_values]
     else:
-        raise ValueError(f"Invalid input unit. Expected {Unit.KELVIN} or {Unit.CELSIUS}, got '{input_unit}'")
+        raise DomainValidationException(
+            f"Invalid input unit. Expected {Unit.KELVIN} or {Unit.CELSIUS}, got '{input_unit}'"
+        )
 
 
 def convert_efficiency_to_fraction(efficiency_values: list[float], input_unit: Unit) -> list[float]:
@@ -127,7 +96,15 @@ def convert_efficiency_to_fraction(efficiency_values: list[float], input_unit: U
     else:
         msg = f"Efficiency unit {input_unit} not supported. Must be one of {', '.join(list(ChartEfficiencyUnit))}"
         logger.error(msg)
-        raise ValueError(msg)
+        raise DomainValidationException(msg)
+
+
+@overload
+def convert_control_margin_to_fraction(control_margin: None, input_unit: Unit) -> None: ...
+
+
+@overload
+def convert_control_margin_to_fraction(control_margin: float, input_unit: Unit) -> float: ...
 
 
 def convert_control_margin_to_fraction(control_margin: float | None, input_unit: Unit) -> float | None:
@@ -144,7 +121,7 @@ def convert_control_margin_to_fraction(control_margin: float | None, input_unit:
             f"Control margin unit {input_unit} not supported. Must be one of {', '.join(list(ChartControlMarginUnit))}"
         )
         logger.error(msg)
-        raise ValueError(msg)
+        raise DomainValidationException(msg)
 
 
 def chart_curves_as_resource_to_dto_format(resource: Resource) -> list[YamlCurve]:
