@@ -1,7 +1,9 @@
 from typing import Literal
 
-from pydantic import Field, field_validator
+from pydantic import Field, field_validator, model_validator
+from pydantic_core.core_schema import ValidationInfo
 
+from libecalc.presentation.yaml.yaml_keywords import EcalcYamlKeywords
 from libecalc.presentation.yaml.yaml_types import YamlBase
 from libecalc.presentation.yaml.yaml_types.components.legacy.energy_usage_model.common import (
     EnergyUsageModelCommon,
@@ -9,10 +11,12 @@ from libecalc.presentation.yaml.yaml_types.components.legacy.energy_usage_model.
 from libecalc.presentation.yaml.yaml_types.components.yaml_expression_type import (
     YamlExpressionType,
 )
+from libecalc.presentation.yaml.yaml_types.models import YamlCompressorWithTurbine
 from libecalc.presentation.yaml.yaml_types.models.model_reference_validation import (
     CompressorEnergyUsageModelModelReference,
     PumpEnergyUsageModelModelReference,
 )
+from libecalc.presentation.yaml.yaml_types.models.yaml_enums import YamlChartType
 
 
 class YamlCompressorSystemCompressor(YamlBase):
@@ -104,6 +108,32 @@ class YamlEnergyUsageModelCompressorSystem(EnergyUsageModelCommon):
 
         return compressors
 
+    @model_validator(mode="after")
+    def forbid_generic_from_input_and_unknown_stages_in_compressor_system(self, info: ValidationInfo):
+        if not info.context:
+            return self
+
+        for compressor in self.compressors:
+            compressor_model = info.context["model_types"][compressor.compressor_model]
+            if isinstance(compressor_model, YamlCompressorWithTurbine):
+                compressor_model = info.context["model_types"][compressor_model.compressor_model]
+            train = getattr(compressor_model, "compressor_train", None)
+            if not train:
+                continue
+
+            stages = getattr(train, EcalcYamlKeywords.models_type_compressor_train_stages.lower(), None)
+            if stages:
+                for stage in stages:
+                    compressor_chart = info.context["model_types"][stage.compressor_chart]
+                    if compressor_chart.chart_type == YamlChartType.GENERIC_FROM_INPUT:
+                        raise ValueError(
+                            f"{compressor_chart.chart_type.value} compressor chart is not supported for {self.type}."
+                        )
+            else:
+                raise ValueError(f"A compressor train with unknown stages is not supported for {self.type}.")
+
+        return self
+
 
 class YamlPumpSystemPump(YamlBase):
     name: str = Field(
